\name{crr}
\alias{crr}
\title{
Competing Risks Regression
}
\description{
regression modeling of subdistribution functions in competing risks
}
\usage{
crr(ftime, fstatus, cov1, cov2, tf, cengroup, failcode=1, cencode=0,
subset, na.action=na.omit, gtol=1e-06, maxiter=10, init)
}
\arguments{
\item{ftime}{
vector of failure/censoring times
}
\item{fstatus}{
vector with a unique code for each failure type and a separate code for
censored observations 
}
\item{cov1}{
matrix (nobs x ncovs) of fixed covariates (either cov1, cov2, or both
are required)
}
\item{cov2}{
matrix of covariates that will be multiplied by functions of time; 
if used, often these covariates would also appear in cov1
to give a prop hazards effect plus a time interaction
}
\item{tf}{
functions of time.  A function that takes a vector of times as
an argument and returns a matrix whose jth column is the value of 
the time function corresponding to the jth column of cov2 evaluated
at the input time vector.  At time \code{tk}, the
model includes the term \code{cov2[,j]*tf(tk)[,j]} as a covariate.
}
\item{cengroup}{
vector with different values for each group with 
a distinct censoring distribution (the censoring distribution
is estimated separately within these groups).  All data in one group, if
missing. 
}
\item{failcode}{
code of fstatus that denotes the failure type of interest
}
\item{cencode}{
code of fstatus that denotes censored observations
}
\item{subset}{
  a logical vector specifying a subset of cases to include in the
  analysis
}
\item{na.action}{
  a function specifying the action to take for any cases missing any of
  ftime, fstatus, cov1, cov2, cengroup, or subset.
}
\item{gtol}{
  iteration stops when a function of the gradient is \code{< gtol}
}
\item{maxiter}{
maximum number of iterations in Newton algorithm (0 computes
scores and var at \code{init}, but performs no iterations)
}
\item{init}{
  initial values of regression parameters (default=all 0)
}
}
\value{
  Returns a list of class crr, with components
  \item{$coef}{the estimated regression coefficients}
  \item{$loglik}{log pseudo-liklihood evaluated at coef}
\item{$score}{derivitives of the log pseudo-likelihood evaluated at coef}
\item{$inf}{-second derivatives of the log pseudo-likelihood}
\item{$var}{estimated variance covariance matrix of coef}
\item{$res}{matrix of residuals giving the
contribution to each score (columns) at each unique failure time
(rows)}
\item{$uftime}{vector of unique failure times}
\item{$bfitj}{jumps in the Breslow-type estimate of the underlying
  sub-distribution cumulative hazard (used by predict.crr())}
\item{$tfs}{the tfs matrix (output of tf(), if used)}
\item{$converged}{TRUE if the iterative algorithm converged.}
}
\details{
Fits the 'proportional subdistribution hazards' regression model
described in Fine and Gray (1999).  This model directly assesses the
effect of covariates on the subdistribution of a particular type of
failure in a competing risks setting.  The method implemented here is
described in the paper as the weighted estimating equation.

The basic model assumes the subdistribution with covariates z is a
constant shift on the complementary log log scale from a baseline
subdistribution function.  This can be generalized by including
interactions of z with functions of time to allow the magnitude of the
shift to change with follow-up time, through the cov2 and tfs
arguments.  For example, if z is a vector of covariate values, and uft
is a vector containing the unique failure times for failures of the
type of interest (sorted in ascending order), then the coefficients a,
b and c in the quadratic (in time) model
\eqn{az+bzt+zt^2}{a*z+b*z*t+c*z*t*t} can be fit
by specifying \code{cov1=z}, \code{cov2=cbind(z,z)},
\code{tf=function(uft) cbind(uft,uft*uft)}. 

This function uses an estimate of the survivor function of the
censoring distribution to reweight contributions to the risk sets for
failures from competing causes.  In a generalization of the methodology
in the paper, the censoring distribution can be estimated separately
within strata defined by the cengroup argument.  If the censoring
distribution is different within groups defined by covariates in the
model, then validity of the method requires using separate estimates of
the censoring distribution within those groups.

The residuals returned are analogous to the Schoenfeld residuals in
ordinary survival models.  Plotting the jth column of res against the
vector of unique failure times checks for lack of fit over time in the
corresponding covariate (column of cov1).
}
\references{
Fine JP and Gray RJ (1999) A proportional hazards model for the
subdistribution of a competing risk.  JASA 94:496-509.
}
\seealso{
\code{\link{predict.crr}} \code{\link{print.crr}} \code{\link{plot.predict.crr}}
}
\examples{
# simulated data to test 
set.seed(10)
ftime <- rexp(200)
fstatus <- sample(0:2,200,replace=TRUE)
cov <- matrix(runif(600),nrow=200)
print(z <- crr(ftime,fstatus,cov))
# convergence:  TRUE 
# coefficients:
# [1]  0.8470 -0.3473 -0.6913
# standard errors:
# [1] 0.4027 0.4402 0.4916
# two-sided p-values:
# [1] 0.035 0.430 0.160
# for failures of type 2
z.p <- predict(z,rbind(c(.1,.5,.8),c(.1,.5,.2)))
plot(z.p,lty=1,color=2:3)
crr(ftime,fstatus,cov,failcode=2)
# convergence:  TRUE 
# coefficients:
# [1] -0.4638  0.4896  0.2331
# standard errors:
# [1] 0.3896 0.4540 0.4256
# two-sided p-values:
# [1] 0.23 0.28 0.58
# quadratic in time for first cov
crr(ftime,fstatus,cov,cbind(cov[,1],cov[,1]),function(Uft) cbind(Uft,Uft^2))
# convergence:  TRUE 
# coefficients:
# [1]  1.3360 -0.3484 -0.6852 -1.1210  0.3897
# standard errors:
# [1] 0.8657 0.4405 0.4909 1.6860 0.6271
# two-sided p-values:
# [1] 0.12 0.43 0.16 0.51 0.53
#last 2 values are the coefs of the cov[,1]*t and cov[,1]*t^2 terms
#additional examples in test.R
}
\keyword{survival}
\eof
\name{cuminc}
\alias{cuminc}
\title{
Cumulative Incidence Analysis
}
\description{
Estimate cumulative incidence functions from competing risks
data and test equality across groups
}
\usage{
cuminc(ftime, fstatus, group, strata, rho=0, cencode=0,
subset, na.action=na.omit)
}
\arguments{
\item{ftime}{
failure time variable
}
\item{fstatus}{
variable with distinct codes for different causes of failure
and also a distinct code for censored observations
}
\item{group}{
estimates will calculated within groups given by distinct values of this
variable.  Tests will compare these groups.  If missing then treated as all
one group (no test statistics)
}
\item{strata}{
stratification variable.  Has no effect on estimates.  Tests will be
stratified on this variable.  (all data in 1 stratum, if missing)
}
\item{rho}{
Power of the weight function used in the tests.
}
\item{cencode}{
value of fstatus variable which indicates the failure time is censored.
}
\item{subset}{
  a logical vector specifying a subset of cases to include in the
  analysis
}
\item{na.action}{
  a function specifying the action to take for any cases missing any of
  ftime, fstatus, group, strata, or subset.
}
}
\value{
A list with components giving the subdistribution estimates for each
cause in each group, and a component giving the test results (if the
number of groups is >1).  The components giving the estimates have names
that are a combination 
of the group name and the cause code.  The estimate for each group and
cause combination is also a list.
\item{$<groupcause>}{
\item{\code{$<groupcause>$time}}{ the times
where the estimates are calculated}
\item{\code{$<groupcause>$est}}{the estimated
sub-distribution functions.  These are step functions (all corners
of the steps given), so they can be plotted using ordinary lines() commands.
Estimates at particular times can be located using the timepoints()
function.}
\item{\code{$<groupcause>$var}}{the estimated variance of
  the estimates, which are estimates of the asymptotic
  variance of Aalen (1978).  }
}

\item{$Tests}{
  If the number of groups is \eqn{>}{>}1, there is also a component at
  the top level giving the test
statistics and p-values for comparing the subdistribution for each
cause across groups.  The test statistics are described in Gray (1988).
}
}
\references{
Gray RJ (1988) A class of K-sample tests for comparing the cumulative
incidence of a competing risk, ANNALS OF STATISTICS, 16:1141-1154.


Kalbfleisch and Prentice (1980) THE ANALYSIS OF FAILURE TIME DATA, p 168-9.


Aalen, O. (1978) Nonparametric estimation of partial transition
probabilities in multiple decrement models, ANNALS OF STATISTICS,
6:534-545.
}
\author{Robert Gray}
\seealso{
\code{\link{plot.cuminc}} \code{\link{timepoints}} \code{\link{print.cuminc}}
}
\examples{
set.seed(2)
ss <- rexp(100)
gg <- factor(sample(1:3,100,replace=TRUE),1:3,c('a','b','c'))
cc <- sample(0:2,100,replace=TRUE)
strt <- sample(1:2,100,replace=TRUE)
print(xx <- cuminc(ss,cc,gg,strt))
#Tests:
#      stat        pv
#1 3.393977 0.1832345
#2 1.989511 0.3698139
#Estimates and Variances:
#$est
#            1         2         3         4         5
#a 1 0.1311269 0.2699184 0.3420625 0.3420625 0.3420625
#b 1 0.2176471 0.2615686        NA        NA        NA
#c 1 0.3816280 0.4889137 0.5723581        NA        NA
#a 2 0.2257601 0.2972171 0.4415053 0.4415053 0.4415053
#b 2 0.3117647 0.5878431        NA        NA        NA
#c 2 0.2160508 0.2607532 0.2607532        NA        NA
#
#$var
#              1           2           3          4          5
#a 1 0.003922836 0.009113464 0.012507959 0.01250796 0.01250796
#b 1 0.005528913 0.006916070          NA         NA         NA
#c 1 0.009854126 0.012351948 0.015575726         NA         NA
#a 2 0.005947601 0.007356628 0.014479506 0.01447951 0.01447951
#b 2 0.007033454 0.010927780          NA         NA         NA
#c 2 0.006497566 0.007867543 0.007867543         NA         NA
plot(xx,lty=1,color=1:6)
# see also test.R, test.out
}
\keyword{survival}
\eof
\name{plot.cuminc}
\alias{plot.cuminc}
\title{
Create Labeled Cumulative Incidence Plots
}
\description{
Plot method for cuminc.  Creates labeled line plots from appropriate
list input, for example, the output from \code{cuminc()}.
}
\usage{
plot.cuminc(x, main=" ", curvlab, ylim=c(0, 1), xlim, wh=2, xlab="Years", 
ylab="Probability", lty=1:length(x), color=1, \dots)
}
\arguments{
\item{x}{
a list, with each component representing one curve in the plot.  Each
component of \code{x} is itself a list whose first component gives the x values
and 2nd component the y values to be plotted.  Although written for
cumulative incidence curves, can in principle be used for any set of lines.
}
\item{main}{
the main title for the plot.
}
\item{curvlab}{
Curve labels for the plot.  Default is \code{names(x)}, or if that is missing,
\code{1:nc}, where \code{nc} is the number of curves in \code{x}.
}
\item{ylim}{
yaxis limits for plot
}
\item{xlim}{
xaxis limits for plot (default is 0 to the largest time in any of the
curves)
}
\item{wh}{
  if a vector of length 2, then the upper right coordinates of the
  legend; otherwise the legend is placed in the upper right corner of
  the plot
}
\item{xlab}{
X axis label 
}
\item{ylab}{
 y axis label
}
\item{lty}{
vector of line types.  Default \code{1:nc} (\code{nc} is the number of
curves in \code{x}).  For color displays, \code{lty=1, color=1:nc}, might
be more appropriate.  If \code{length(lty)<nc}, then \code{lty[1]} is
used for all. 
}
\item{color}{
  vector of colors.  If \code{length(color)<nc}, then the \code{color[1]} is
  used for all.
  }
\item{...}{
additional arguments passed to the initial call of the plot function.
}}
\value{
No value is returned.  
}
\seealso{ \code{\link{cuminc}} }
%\examples{
%#see help(cuminc)
%}
\keyword{survival}
\keyword{hplot}
% Converted by Sd2Rd version 1.10.
\eof
\name{plot.predict.crr}
\alias{plot.predict.crr}
\title{
Plot estimated subdistribution functions
}
\description{
plot method for \code{predict.crr}
}
\usage{
plot.predict.crr(x, lty=1:(ncol(x)-1), color=1,  ylim=c(0, max(x[, -1])),
xmin=0, xmax=max(x[, 1]), \dots)
}
\arguments{
\item{x}{
Output from \code{predict.crr}
}
\item{lty}{
vector of line types. If length is \eqn{<}{<} \# curves, then
\code{lty[1]} is used for all. 
}
\item{color}{
vector of line colors.  If length is \eqn{<}{<} \# curves, then
\code{color[1]} is used for all. 
}
\item{ylim}{
range of y-axis (vector of length two)
}
\item{xmin}{
lower limit of x-axis (often 0, the default)
}
\item{xmax}{
upper limit of x-axis
}
\item{...}{
Other arguments to plot
}}
\section{Side Effects}{
plots the subdistribution functions estimated by \code{predict.crr}, by
default using a different line type for each curve
}
\seealso{
\code{\link{crr}} \code{\link{predict.crr}}
}
\keyword{survival}
% Converted by Sd2Rd version 1.10.
\eof
\name{predict.crr}
\alias{predict.crr}
\title{
Estimate subdistribution functions from crr output
}
\description{
predict method for crr
}
\usage{
predict.crr(object, cov1, cov2, \dots)
}
\arguments{
\item{object}{
output from crr
}
\item{cov1, cov2}{
each row of cov1 and cov2 is a set of covariate values where the
subdistribution should be estimated.  The columns of cov1 and cov2 must
be in the same order as in the original call to crr.  Each must be
given if present in the original call to crr.
}
\item{...}{
additional arguments are ignored (included for compatibility with generic).
}
}
\value{
Returns a matrix with the unique type 1 failure times in the first
column, and the other columns giving the estimated subdistribution
function corresponding to the covariate combinations in the rows of cov1
and cov2, at each failure time (the value that the estimate jumps to at
that failure time).
}
\details{
Computes \eqn{1-\exp(-B(t))}{1-exp(-B(t))}, where \eqn{B(t)}{B(t)} is
the estimated cumulative 
sub-distribution hazard obtained for the specified covariate values,
obtained from the Breslow-type estimate of the underlying hazard and
the estimated regression coefficients.
}
\seealso{
\code{\link{crr}} \code{\link{plot.predict.crr}}
}
\keyword{survival}
% Converted by Sd2Rd version 1.10.
\eof
\name{print.crr}
\alias{print.crr}
\title{
prints summary of a crr object
}
\description{
print method for crr objects
}
\usage{
print.crr(x, \dots)
}
\arguments{
\item{x}{
crr object (output from \code{crr()})
}
\item{...}{additional arguments to \code{print()}}
}
\details{
prints the convergence status, the estimated coefficients, the
estimated standard errors, and the two-sided p-values for the test of
the individual coefficients equal to 0. (If convergence is false
everything else may be meaningless.)
}
\seealso{
\code{\link{crr}}
}
\keyword{survival}
% Converted by Sd2Rd version 1.10.
\eof
\name{print.cuminc}
\alias{print.cuminc}
\title{Print cuminc objects}
\description{
A print method for objects of class cuminc (output from \code{cuminc()}).
}
\usage{
print.cuminc(x, ntp=4, maxtime, \dots)
}
\arguments{
 \item{x}{an object of class cuminc}
 \item{ntp}{number of timepoints where estimates are printed}
 \item{maxtime}{the maximum timepoint where values are printed.  The
   default is the maximum time in the curves in \code{x}}
 \item{...}{additional arguments to \code{print()}}
}
\details{
Prints the test statistics and p-values (if present in \code{x}), and for each
estimated cumulative incidence curve prints its value and estimated
variance at a vector of times.  The times are chosen between 0 and
maxtime using the \code{pretty()} function.
}
\author{Robert Gray}

\seealso{ \code{\link{cuminc}} }

%\examples{
%#see help(cuminc)
%}
\keyword{survival }%-- one or more ...
\eof
\name{timepoints}
\alias{timepoints}
\title{
Calculate Estimates at Specific Timepoints
}
\description{
Find values at specified timepoints from curves specified as all
corners of step functions.
}
\usage{
timepoints(w, times)
}
\arguments{
\item{w}{
a list containing the estimates, with points for all corners of the
step function.  (Usually created by cuminc.)
Each component in the list contains the estimate for a different group.
Each component has components giving times, function estimates, and
variances (see cuminc)
}
\item{times}{
vector of times where estimates are needed
}}
\value{
  A list with components
  \item{$est}{a matrix of estimates of the subdistributions with a row for
each component in \code{w} and a column for each time}
  \item{$var}{a matrix giving the corresponding variances.}
}
\seealso{
\code{\link{cuminc}}
}
\keyword{survival}
% Converted by Sd2Rd version 1.10.
\eof
